@@ -12,7 +12,7 @@ class TestCheck(Check):
 
     @property
     def this_check(self):
-        """Bolierplate."""
+        """Boilerplate."""
         return chk
 
     def test_sample_phrases(self):
